<?php

/**
* Get started notice
*/

add_action( 'wp_ajax_transport_solutions_dismissed_notice_handler', 'transport_solutions_ajax_notice_handler' );

/**
 * AJAX handler to store the state of dismissible notices.
 */
function transport_solutions_ajax_notice_handler() {
    if ( isset( $_POST['type'] ) ) {
        // Pick up the notice "type" - passed via jQuery (the "data-notice" attribute on the notice)
        $type = sanitize_text_field( wp_unslash( $_POST['type'] ) );
        // Store it in the options table
        update_option( 'dismissed-' . $type, TRUE );
    }
}

function transport_solutions_deprecated_hook_admin_notice() {
        // Check if it's been dismissed...
        if ( ! get_option('dismissed-get_started', FALSE ) ) { ?>

            <?php
            $current_screen = get_current_screen();
				if ($current_screen->id !== 'appearance_page_transport-solutions-guide-page') {
             $transport_solutions_comments_theme = wp_get_theme(); ?>
            <div class="transport-solutions-notice-wrapper updated notice notice-get-started-class is-dismissible" data-notice="get_started">
			<div class="transport-solutions-notice">
				<div class="transport-solutions-notice-img">
					<img src="<?php echo esc_url(get_template_directory_uri() . '/assets/images/admin-logo.png'); ?>" alt="<?php esc_attr_e('logo', 'transport-solutions'); ?>">
				</div>
				<div class="transport-solutions-notice-content">
					<div class="transport-solutions-notice-heading"><?php esc_html_e('Thanks for installing ','transport-solutions'); ?><?php echo esc_html( $transport_solutions_comments_theme ); ?></div>
					<p><?php printf(__('In order to fully benefit from everything our theme has to offer, please make sure you visit our <a href="%s">For Premium Options</a>.', 'transport-solutions'), esc_url(admin_url('themes.php?page=transport-solutions-guide-page'))); ?></p>
					<?php if (is_child_theme()) { ?>
						<?php $child_theme = wp_get_theme(); ?>
						<?php printf(esc_html__('You\'re using %1$s theme, It\'s a child theme of %2$s.', 'transport-solutions'), '<strong>' . $child_theme->Name . '</strong>', '<strong>' . esc_html__('transport_solutions', 'transport-solutions') . '</strong>'); 
						?>
						<?php
						$copy_link_args = array(
							'page' => 'transport-solutions',
							'action' => 'show_copy_settings',
						);
						$copy_link = add_query_arg($copy_link_args, admin_url('themes.php'));
						?>
						<?php printf('%s <a href="%s" class="go-to-setting">%s</a>', esc_html__('Now you can copy setting data from parent theme to this child theme', 'transport-solutions'), esc_url($copy_link), esc_html__('Copy Settings', 'transport-solutions')); ?>
					<?php } ?>
				</div>
			</div>
		</div>
        <?php }
	}
}

add_action( 'admin_notices', 'transport_solutions_deprecated_hook_admin_notice' );

add_action( 'admin_menu', 'transport_solutions_getting_started' );
function transport_solutions_getting_started() {
	add_theme_page( esc_html__('Get Started', 'transport-solutions'), esc_html__('Get Started', 'transport-solutions'), 'edit_theme_options', 'transport-solutions-guide-page', 'transport_solutions_test_guide');
}

function transport_solutions_admin_enqueue_scripts() {
	wp_enqueue_style( 'transport-solutions-admin-style', esc_url( get_template_directory_uri() ).'/css/main.css' );
	wp_enqueue_script( 'transport-solutions-admin-script', get_template_directory_uri() . '/js/transport-solutions-admin-script.js', array( 'jquery' ), '', true );
    wp_localize_script( 'transport-solutions-admin-script', 'transport_solutions_ajax_object',
        array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
    );
}
add_action( 'admin_enqueue_scripts', 'transport_solutions_admin_enqueue_scripts' );

if ( ! defined( 'TRANSPORT_SOLUTION_DOCS_FREE' ) ) {
define('TRANSPORT_SOLUTION_DOCS_FREE',__('https://www.misbahwp.com/docs/transport-solutions-free-docs/','transport-solutions'));
}
if ( ! defined( 'TRANSPORT_SOLUTION_DOCS_PRO' ) ) {
define('TRANSPORT_SOLUTION_DOCS_PRO',__('https://www.misbahwp.com/docs/transport-solutions-pro-docs','transport-solutions'));
}
if ( ! defined( 'TRANSPORT_SOLUTION_BUY_NOW' ) ) {
define('TRANSPORT_SOLUTION_BUY_NOW',__('https://www.misbahwp.com/themes/transport-wordpress-theme/','transport-solutions'));
}
if ( ! defined( 'TRANSPORT_SOLUTION_SUPPORT_FREE' ) ) {
define('TRANSPORT_SOLUTION_SUPPORT_FREE',__('https://wordpress.org/support/theme/transport-solutions','transport-solutions'));
}
if ( ! defined( 'TRANSPORT_SOLUTION_REVIEW_FREE' ) ) {
define('TRANSPORT_SOLUTION_REVIEW_FREE',__('https://wordpress.org/support/theme/transport-solutions/reviews/#new-post','transport-solutions'));
}
if ( ! defined( 'TRANSPORT_SOLUTION_DEMO_PRO' ) ) {
define('TRANSPORT_SOLUTION_DEMO_PRO',__('https://www.misbahwp.com/demo/transport-solutions','transport-solutions'));
}
if( ! defined( 'TRANSPORT_SOLUTION_THEME_BUNDLE' ) ) {
define('TRANSPORT_SOLUTION_THEME_BUNDLE',__('https://www.misbahwp.com/themes/wordpress-bundle/','transport-solutions'));
}


function transport_solutions_test_guide() { ?>
	<?php $transport_solutions_theme = wp_get_theme(); ?>
	<div class="wrap" id="main-page">
		<div id="lefty">
			<div id="admin_links">
				<a href="<?php echo esc_url( TRANSPORT_SOLUTION_DOCS_FREE ); ?>" target="_blank" class="blue-button-1"><?php esc_html_e( 'Documentation', 'transport-solutions' ) ?></a>
				<a href="<?php echo esc_url( admin_url('customize.php') ); ?>" id="customizer" target="_blank"><?php esc_html_e( 'Customize', 'transport-solutions' ); ?> </a>
				<a class="blue-button-1" href="<?php echo esc_url( TRANSPORT_SOLUTION_SUPPORT_FREE ); ?>" target="_blank" class="btn3"><?php esc_html_e( 'Support', 'transport-solutions' ) ?></a>
				<a class="blue-button-2" href="<?php echo esc_url( TRANSPORT_SOLUTION_REVIEW_FREE ); ?>" target="_blank" class="btn4"><?php esc_html_e( 'Review', 'transport-solutions' ) ?></a>
			</div>
			<div id="description">
				<h3><?php esc_html_e('Welcome! Thank you for choosing ','transport-solutions'); ?><?php echo esc_html( $transport_solutions_theme ); ?>  <span><?php esc_html_e('Version: ', 'transport-solutions'); ?><?php echo esc_html($transport_solutions_theme['Version']);?></span></h3>
				<img class="img_responsive" style="width:100%;" src="<?php echo esc_url( get_template_directory_uri() ); ?>/screenshot.png">
				<div id="description-insidee">
					<?php
						$transport_solutions_theme = wp_get_theme();
						echo wp_kses_post( apply_filters( 'misbah_theme_description', esc_html( $transport_solutions_theme->get( 'Description' ) ) ) );
					?>
				</div>
			</div>
		</div>

		<div id="righty">
			<div class="postboxxx donate">
				<h3 class="hndle"><?php esc_html_e( 'Upgrade to Premium', 'transport-solutions' ); ?></h3>
				<div class="insidee">
					<p><?php esc_html_e('Discover upgraded pro features with premium version click to upgrade.','transport-solutions'); ?></p>
					<div id="admin_pro_links">
						<a class="blue-button-2" href="<?php echo esc_url( TRANSPORT_SOLUTION_BUY_NOW ); ?>" target="_blank"><?php esc_html_e( 'Go Pro', 'transport-solutions' ); ?></a>
						<a class="blue-button-1" href="<?php echo esc_url( TRANSPORT_SOLUTION_DEMO_PRO ); ?>" target="_blank"><?php esc_html_e( 'Live Demo', 'transport-solutions' ) ?></a>
						<a class="blue-button-2" href="<?php echo esc_url( TRANSPORT_SOLUTION_DOCS_PRO ); ?>" target="_blank"><?php esc_html_e( 'Pro Docs', 'transport-solutions' ) ?></a>
					</div>
				</div>

				<h3 class="hndle bundle"><?php esc_html_e( 'Go For Theme Bundle', 'transport-solutions' ); ?></h3>
				<div class="insidee theme-bundle">
					<p class="offer"><?php esc_html_e('Get 80+ Perfect WordPress Theme In A Single Package at just $79."','transport-solutions'); ?></p>
					<p class="coupon"><?php esc_html_e('Exclusive Offer !! Get Our Theme Pack of 80+ WordPress Themes At 10% Off','transport-solutions'); ?><span class="coupon-code"><?php esc_html_e('"Themespack10"','transport-solutions'); ?></span></p>
					<div id="admin_pro_linkss">
						<a class="blue-button-1" href="<?php echo esc_url( TRANSPORT_SOLUTION_THEME_BUNDLE ); ?>" target="_blank"><?php esc_html_e( 'Theme Bundle', 'transport-solutions' ) ?></a>
					</div>
				</div>
				<div class="d-table">
			    <ul class="d-column">
			      <li class="feature"><?php esc_html_e('Features','transport-solutions'); ?></li>
			      <li class="free"><?php esc_html_e('Pro','transport-solutions'); ?></li>
			      <li class="plus"><?php esc_html_e('Free','transport-solutions'); ?></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('24hrs Priority Support','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Kirki Framework','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('One Click Demo Import','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Secton Reordering','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Enable / Disable Option','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Posttype','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Multiple Sections','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Color Pallete','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Widgets','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-yes"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Page Templates','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Advance Typography','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
			    <ul class="d-row">
			      <li class="points"><?php esc_html_e('Section Background Image / Color ','transport-solutions'); ?></li>
			      <li class="right"><span class="dashicons dashicons-yes"></span></li>
			      <li class="wrong"><span class="dashicons dashicons-no"></span></li>
			    </ul>
	  		</div>
			</div>
		</div>
	</div>

<?php } ?>
